@@ -1,11 +1,16 @@
-import jsbridge
+import json
 from xciterst.citations import CitationInfo, CitationCluster
 
-class ZoteroJSONEncoder(jsbridge.network.JSObjectEncoder):
+class ZoteroJSONEncoder(json.JSONEncoder):
     """An encoder for our JSON objects."""
     def default(self, obj):
         if isinstance(obj, CitationInfo):
-            retval = { 'id': obj.id}
+            retval = {}
+            # need to make a decision here at some point
+            if obj.citekey: 
+                retval['easyKey'] = obj.citekey
+            elif obj.id:
+                retval['id'] = obj.id
             if obj.prefix: retval['prefix'] = "%s "%(obj.prefix) # ensure spaces in prefix, suffix
             if obj.suffix: retval['suffix'] = " %s"%(obj.suffix)
             if obj.label: retval['label'] = obj.label
@@ -17,6 +22,5 @@ class ZoteroJSONEncoder(jsbridge.network.JSObjectEncoder):
             return { 'citationItems': obj.citations,
                      'properties'   : { 'index'     : obj.index,
                                         'noteIndex' : obj.note_index } }
-        else: return json.JSONEncoder.default(self, obj)
+        else: return super(ZoteroJSONEncoder, self).default(self, obj)
 
-jsbridge.network.encoder = ZoteroJSONEncoder()
